summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorLiam Dyer <liamcdyer@gmail.com>2025-04-09 17:25:57 -0400
committerGitHub <noreply@github.com>2025-04-09 17:25:57 -0400
commitafb04695977c300478b42e06c78c656358616df3 (patch)
tree5ebe60bf9d468eb8659d86708b7d13e56c4923fe
parent3e3af5d4ba9ab23c5c094077dc5c8918308897a5 (diff)
downloaddots-afb04695977c300478b42e06c78c656358616df3.tar.gz
feat: switch nvim-cmp for blink.cmp (#1426)
-rw-r--r--nvim/init.lua164
-rw-r--r--nvim/lua/kickstart/plugins/autopairs.lua10
2 files changed, 73 insertions, 101 deletions
--
-- No, but seriously. Please read `:help ins-completion`, it is really good!
- mapping = cmp.mapping.preset.insert {
- -- Select the [n]ext item
- ['<C-n>'] = cmp.mapping.select_next_item(),
- -- Select the [p]revious item
- ['<C-p>'] = cmp.mapping.select_prev_item(),
-
- -- Scroll the documentation window [b]ack / [f]orward
- ['<C-b>'] = cmp.mapping.scroll_docs(-4),
- ['<C-f>'] = cmp.mapping.scroll_docs(4),
-
- -- Accept ([y]es) the completion.
- -- This will auto-import if your LSP supports it.
- -- This will expand snippets if the LSP sent a snippet.
- ['<C-y>'] = cmp.mapping.confirm { select = true },
-
- -- If you prefer more traditional completion keymaps,
- -- you can uncomment the following lines
- --['<CR>'] = cmp.mapping.confirm { select = true },
- --['<Tab>'] = cmp.mapping.select_next_item(),
- --['<S-Tab>'] = cmp.mapping.select_prev_item(),
-
- -- Manually trigger a completion from nvim-cmp.
- -- Generally you don't need this, because nvim-cmp will display
- -- completions whenever it has completion options available.
- ['<C-Space>'] = cmp.mapping.complete {},
-
- -- Think of <c-l> as moving to the right of your snippet expansion.
- -- So if you have a snippet that's like:
- -- function $name($args)
- -- $body
- -- end
- --
- -- <c-l> will move you to the right of each of the expansion locations.
- -- <c-h> is similar, except moving you backwards.
- ['<C-l>'] = cmp.mapping(function()
- if luasnip.expand_or_locally_jumpable() then
- luasnip.expand_or_jump()
- end
- end, { 'i', 's' }),
- ['<C-h>'] = cmp.mapping(function()
- if luasnip.locally_jumpable(-1) then
- luasnip.jump(-1)
- end
- end, { 'i', 's' }),
+ --
+ -- All presets have the following mappings:
+ -- <tab>/<s-tab>: move to right/left of your snippet expansion
+ -- <c-space>: Open menu or open docs if already open
+ -- <c-n>/<c-p> or <up>/<down>: Select next/previous item
+ -- <c-e>: Hide menu
+ -- <c-k>: Toggle signature help
+ --
+ -- See :h blink-cmp-config-keymap for defining your own keymap
+ preset = 'default',
- -- For more advanced Luasnip keymaps (e.g. selecting choice nodes, expansion) see:
- -- https://github.com/L3MON4D3/LuaSnip?tab=readme-ov-file#keymaps
- },
- sources = {
- {
- name = 'lazydev',
- -- set group index to 0 to skip loading LuaLS completions as lazydev recommends it
- group_index = 0,
- },
- { name = 'nvim_lsp' },
- { name = 'luasnip' },
- { name = 'path' },
- { name = 'nvim_lsp_signature_help' },
+ -- For more advanced Luasnip keymaps (e.g. selecting choice nodes, expansion) see:
+ -- https://github.com/L3MON4D3/LuaSnip?tab=readme-ov-file#keymaps
+ },
+
+ appearance = {
+ -- 'mono' (default) for 'Nerd Font Mono' or 'normal' for 'Nerd Font'
+ -- Adjusts spacing to ensure icons are aligned
+ nerd_font_variant = 'mono',
+ },
+
+ completion = {
+ -- By default, you may press `<c-space>` to show the documentation.
+ -- Optionally, set `auto_show = true` to show the documentation after a delay.
+ documentation = { auto_show = false, auto_show_delay_ms = 500 },
+ },
+
+ sources = {
+ default = { 'lsp', 'path', 'snippets', 'lazydev' },
+ providers = {
+ lazydev = { module = 'lazydev.integrations.blink', score_offset = 100 },
},
- }
- end,
+ },
+
+ snippets = { preset = 'luasnip' },
+
+ -- Blink.cmp includes an optional, recommended rust fuzzy matcher,
+ -- which automatically downloads a prebuilt binary when enabled.
+ --
+ -- By default, we use the Lua implementation instead, but you may enable
+ -- the rust implementation via `'prefer_rust_with_warning'`
+ --
+ -- See :h blink-cmp-config-fuzzy for more information
+ fuzzy = { implementation = 'lua' },
+
+ -- Shows a signature help window while you type arguments for a function
+ signature = { enabled = true },
+ },
},
{ -- You can easily change to a different colorscheme.
diff --git a/nvim/lua/kickstart/plugins/autopairs.lua b/nvim/lua/kickstart/plugins/autopairs.lua
index 87a7e5f..386d392 100644
--- a/nvim/lua/kickstart/plugins/autopairs.lua
+++ b/nvim/lua/kickstart/plugins/autopairs.lua
@@ -4,13 +4,5 @@
return {
'windwp/nvim-autopairs',
event = 'InsertEnter',
- -- Optional dependency
- dependencies = { 'hrsh7th/nvim-cmp' },
- config = function()
- require('nvim-autopairs').setup {}
- -- If you want to automatically add `(` after selecting a function or method
- local cmp_autopairs = require 'nvim-autopairs.completion.cmp'
- local cmp = require 'cmp'
- cmp.event:on('confirm_done', cmp_autopairs.on_confirm_done())
- end,
+ opts = {},
}
diff --git a/nvim/init.lua b/nvim/init.lua
index f41bc83..c1d5cac 100644
--- a/nvim/init.lua
+++ b/nvim/init.lua
@@ -394,8 +394,8 @@ require('lazy').setup({
-- Useful status updates for LSP.
{ 'j-hui/fidget.nvim', opts = {} },
- -- Allows extra capabilities provided by nvim-cmp
- 'hrsh7th/cmp-nvim-lsp',
+ -- Allows extra capabilities provided by blink.cmp
+ 'saghen/blink.cmp',
},
config = function()
-- Brief aside: **What is LSP?**
@@ -562,10 +562,9 @@ require('lazy').setup({
-- LSP servers and clients are able to communicate to each other what features they support.
-- By default, Neovim doesn't support everything that is in the LSP specification.
- -- When you add nvim-cmp, luasnip, etc. Neovim now has *more* capabilities.
- -- So, we create new capabilities with nvim cmp, and then broadcast that to the servers.
- local capabilities = vim.lsp.protocol.make_client_capabilities()
- capabilities = vim.tbl_deep_extend('force', capabilities, require('cmp_nvim_lsp').default_capabilities())
+ -- When you add blink.cmp, luasnip, etc. Neovim now has *more* capabilities.
+ -- So, we create new capabilities with blink.cmp, and then broadcast that to the servers.
+ local capabilities = require('blink.cmp').get_lsp_capabilities()
-- Enable the following language servers
-- Feel free to add/remove any LSPs that you want here. They will automatically be installed.
@@ -684,12 +683,14 @@ require('lazy').setup({
},
{ -- Autocompletion
- 'hrsh7th/nvim-cmp',
- event = 'InsertEnter',
+ 'saghen/blink.cmp',
+ event = 'VimEnter',
+ version = '1.*',
dependencies = {
- -- Snippet Engine & its associated nvim-cmp source
+ -- Snippet Engine
{
'L3MON4D3/LuaSnip',
+ version = '2.*',
build = (function()
-- Build Step is needed for regex support in snippets.
-- This step is not supported in many windows environments.
@@ -710,95 +711,74 @@ require('lazy').setup({
-- end,
-- },
},
+ opts = {},
},
- 'saadparwaiz1/cmp_luasnip',
-
- -- Adds other completion capabilities.
- -- nvim-cmp does not ship with all sources by default. They are split
- -- into multiple repos for maintenance purposes.
- 'hrsh7th/cmp-nvim-lsp',
- 'hrsh7th/cmp-path',
- 'hrsh7th/cmp-nvim-lsp-signature-help',
+ 'folke/lazydev.nvim',
},
- config = function()
- -- See `:help cmp`
- local cmp = require 'cmp'
- local luasnip = require 'luasnip'
- luasnip.config.setup {}
-
- cmp.setup {
- snippet = {
- expand = function(args)
- luasnip.lsp_expand(args.body)
- end,
- },
- completion = { completeopt = 'menu,menuone,noinsert' },
-
- -- For an understanding of why these mappings were
- -- chosen, you will need to read `:help ins-completion`
+ --- @module 'blink.cmp'
+ --- @type blink.cmp.Config
+ opts = {
+ keymap = {
+ -- 'default' (recommended) for mappings similar to built-in completions
+ -- <c-y> to accept ([y]es) the completion.
+ -- This will auto-import if your LSP supports it.
+ -- This will expand snippets if the LSP sent a snippet.
+ -- 'super-tab' for tab to accept
+ -- 'enter' for enter to accept
+ -- 'none' for no mappings
+ --
+ -- For an understanding of why the 'default' preset is recommended,
+ -- you will need to read `:help ins-completion`